Erin
====

|image0|

**Batteries Included**

| |image1| |image2| |image3| |image4| |image5|

-----------------------------------------------

What is Erin?
^^^^^^^^^^^^^

Erin is an initiative to build a bot development framework like how
flask is a framework for web applications. It is built on top of the
`discord.py`_ library and supports all of it's extensions by default.

Can I get started with Erin today?
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Yes, Erin works out of the box with all `discord.py`_ `extensions`_. You
can read how to set it up in the `documentation`_. However, keep in mind
that this project has not even released a pre-alpha yet. This is because
we are still deliberating core architecture and we want to get it right
the first time. As a result expect plenty of changes to the API without
any notice at all.

.. _discord.py: https://github.com/Rapptz/discord.py
.. _extensions: https://discordpy.readthedocs.io/en/stable/ext/commands/api.html#discord.ext.commands.Bot.load_extension
.. _documentation: https://erin.readthedocs.io/en/latest/?badge=latest

.. |image0| image:: https://i.imgur.com/ffkXdcI.gif
   :width: 100px
   :target: https://erin.readthedocs.io/en/latest/?badge=latest
.. |image1| image:: https://travis-ci.com/DiscordFederation/Erin.svg?branch=master
   :target: https://travis-ci.com/DiscordFederation/Erin
.. |image2| image:: https://ci.appveyor.com/api/projects/status/dm6iw684c1lgji74?svg=true
   :target: https://ci.appveyor.com/project/daegontaven/erin
.. |image3| image:: https://api.codeclimate.com/v1/badges/213ee8d6348a385e5df7/maintainability
   :target: https://codeclimate.com/github/DiscordFederation/Erin/maintainability
.. |image4| image:: https://codecov.io/gh/DiscordFederation/Erin/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/DiscordFederation/Erin
.. |image5| image:: https://readthedocs.org/projects/erin/badge/?version=latest
   :target: https://erin.readthedocs.io/en/latest/?badge=latest
